@@ -1,6 +1,7 @@
 """
 Plot functions for spatial data
 """
+from spharpy._deprecation import convert_coordinates
 
 import matplotlib as mpl
 import matplotlib.pyplot as plt
@@ -47,9 +48,10 @@ def scatter(coordinates, ax=None):
 
     Parameters
     ----------
-    coordinates : Coordinates
+    coordinates : :class:`spharpy.samplings.Coordinates`, :doc:`pf.Coordinates <pyfar:classes/pyfar.coordinates>`
+        The coordinates to be plotted
 
-    """
+    """ # noqa: 501
     fig = plt.gcf()
     if ax is None:
         ax = plt.gca() if fig.axes else plt.axes(projection='3d')
@@ -57,6 +59,7 @@ def scatter(coordinates, ax=None):
     if '3d' not in ax.name:
         raise ValueError("The projection of the axis needs to be '3d'")
 
+    coordinates = convert_coordinates(coordinates)
     ax.scatter(coordinates.x, coordinates.y, coordinates.z)
     ax.set_xlabel('X')
     ax.set_ylabel('Y')
@@ -75,7 +78,7 @@ def _triangulation_sphere(sampling, data):
 
     Parameters
     ----------
-    sampling : Coordinates
+    sampling : :class:`spharpy.samplings.Coordinates`, :doc:`pf.Coordinates <pyfar:classes/pyfar.coordinates>`
         Coordinate object for which the triangulation is calculated
     xyz : list of arrays
         x, y, and z values of the data points in the triangulation
@@ -84,7 +87,8 @@ def _triangulation_sphere(sampling, data):
     -------
     triangulation : matplotlib Triangulation
 
-    """
+    """ # noqa: 501
+    sampling = convert_coordinates(sampling)
     x, y, z = sph2cart(
         np.abs(data),
         sampling.elevation,
@@ -112,7 +116,7 @@ def interpolate_data_on_sphere(
 
     Parameters
     ----------
-    sampling : Coordinates
+    sampling : :class:`spharpy.samplings.Coordinates`, :doc:`pf.Coordinates <pyfar:classes/pyfar.coordinates>`
         The coordinates at which the data is sampled.
     data : ndarray, double
         The sampled data points.
@@ -134,7 +138,8 @@ def interpolate_data_on_sphere(
     Internally, matplotlibs LinearTriInterpolator or CubicTriInterpolator
     are used.
 
-    """
+    """ # noqa: 501
+    sampling = convert_coordinates(sampling)
     lats = sampling.latitude
     lons = sampling.longitude
 
@@ -232,7 +237,7 @@ def pcolor_sphere(
 
     Parameters
     ----------
-    coordinates : Coordinates
+    coordinates : :class:`spharpy.samplings.Coordinates`, :doc:`pf.Coordinates <pyfar:classes/pyfar.coordinates>`
         Coordinates defining a sphere
     data : ndarray, double
         Data for each angle, must have size corresponding to the number of
@@ -248,7 +253,8 @@ def pcolor_sphere(
     show : boolean, optional
         Whether to show the figure or not
 
-    """
+    """ # noqa: 501
+    coordinates = convert_coordinates(coordinates)
     tri, xyz = _triangulation_sphere(coordinates, np.ones_like(data))
     fig = plt.gcf()
 
@@ -318,7 +324,7 @@ def balloon_wireframe(
 
     Parameters
     ----------
-    coordinates : Coordinates
+    coordinates : :class:`spharpy.samplings.Coordinates`, :doc:`pf.Coordinates <pyfar:classes/pyfar.coordinates>`
         Coordinates defining a sphere
     data : ndarray, double
         Data for each angle, must have size corresponding to the number of
@@ -330,7 +336,8 @@ def balloon_wireframe(
         activated by default of the data is complex valued.
     show : boolean, optional
         Whether to show the figure or not
-    """
+    """ # noqa: 501
+    coordinates = convert_coordinates(coordinates)
     tri, xyz = _triangulation_sphere(coordinates, data)
     fig = plt.gcf()
 
@@ -413,7 +420,7 @@ def balloon(
 
     Parameters
     ----------
-    coordinates : Coordinates
+    coordinates : :class:`spharpy.samplings.Coordinates`, :doc:`pf.Coordinates <pyfar:classes/pyfar.coordinates>`
         Coordinates defining a sphere
     data : ndarray, double
         Data for each angle, must have size corresponding to the number of
@@ -425,7 +432,9 @@ def balloon(
         activated by default of the data is complex valued.
     show : boolean, optional
         Wheter to show the figure or not
-    """
+    """ # noqa: 501
+    coordinates = convert_coordinates(coordinates)
+
     tri, xyz = _triangulation_sphere(coordinates, data)
     fig = plt.gcf()
 
@@ -482,7 +491,7 @@ def voronoi_cells_sphere(sampling, round_decimals=13, ax=None):
 
     Parameters
     ----------
-    sampling : SamplingSphere
+    sampling : :class:`spharpy.samplings.SamplingSphere`, :doc:`pf.Coordinates <pyfar:classes/pyfar.coordinates>`
         Sampling as SamplingSphere object
     round_decimals : int
         Decimals to be rounded to for eliminating duplicate points in
@@ -491,7 +500,8 @@ def voronoi_cells_sphere(sampling, round_decimals=13, ax=None):
         The subplot axes to use for plotting. The used projection needs to be
         '3d'.
 
-    """
+    """ # noqa: 501
+    sampling = convert_coordinates(sampling)
     sv = spherical_voronoi(sampling, round_decimals=round_decimals)
     sv.sort_vertices_of_regions()
     points = sampling.cartesian.T
@@ -602,17 +612,16 @@ def pcolor_map(
 
     Parameters
     ----------
-    latitude: ndarray, double
-        Geodetic latitude angle of the map, must be in [-pi/2, pi/2]
-    longitude: ndarray, double
-        Geodetic longitude angle of the map, must be in [-pi, pi]
+    coordinates : :class:`spharpy.samplings.Coordinates`, :doc:`pf.Coordinates <pyfar:classes/pyfar.coordinates>`
+        Coordinates defining a sphere
     data: ndarray, double
         Data for each angle, must have size corresponding to the number of
         points given in coordinates.
     show : boolean, optional
         Wheter to show the figure or not
 
-    """
+    """ # noqa: 501
+    coordinates = convert_coordinates(coordinates)
     tri = mtri.Triangulation(coordinates.longitude, coordinates.latitude)
     if refine is not None:
         subdiv = refine if isinstance(refine, int) else 2
@@ -694,6 +703,7 @@ def contour_map(
         Wheter to show the figure or not
 
     """
+    coordinates = convert_coordinates(coordinates)
     fig = plt.gcf()
 
     res = int(np.ceil(np.sqrt(coordinates.n_points)))
@@ -750,7 +760,7 @@ def contour(
         coordinates, data, limits=None, cmap=cm.viridis, show=True, ax=None):
     """
     Plot the map projection of data points sampled on a spherical surface.
-    The data has to be real.
+    The data has to be real-valued.
 
     Notes
     -----
@@ -759,17 +769,16 @@ def contour(
 
     Parameters
     ----------
-    latitude: ndarray, double
-        Geodetic latitude angle of the map, must be in [-pi/2, pi/2]
-    longitude: ndarray, double
-        Geodetic longitude angle of the map, must be in [-pi, pi]
+    coordinates : :class:`spharpy.samplings.Coordinates`, :doc:`pf.Coordinates <pyfar:classes/pyfar.coordinates>`
+        Coordinates defining a sphere
     data: ndarray, double
         Data for each angle, must have size corresponding to the number of
         points given in coordinates.
     show : boolean, optional
         Wheter to show the figure or not
 
-    """
+    """ # noqa: 501
+    coordinates = convert_coordinates(coordinates)
     lat_deg = coordinates.latitude * 180/np.pi
     lon_deg = coordinates.longitude * 180/np.pi
     fig = plt.gcf()
