@@ -2,9 +2,10 @@ import numpy as np
 import numpy.testing as npt
 import pytest
 
-import spharpy
+from spharpy.samplings import cart2latlon, cart2sph
 from spharpy.samplings.coordinates import Coordinates, SamplingSphere
-from spharpy.samplings import sph2cart, cart2sph, cart2latlon
+
+import pyfar as pf
 
 
 def test_coordinates_init():
@@ -18,6 +19,19 @@ def test_coordinates_init_val():
     assert isinstance(coords, Coordinates)
 
 
+def test_to_pyfar():
+    coords = Coordinates(1, 0, 0)
+    pyfar_coords = coords.to_pyfar()
+    np.testing.assert_allclose(pyfar_coords.get_cart(), coords.cartesian.T)
+
+
+def test_from_pyfar():
+    pyfar_coords = pf.Coordinates(1, 0, 0)
+    spharpy_coords = Coordinates.from_pyfar(pyfar_coords)
+    np.testing.assert_allclose(
+        pyfar_coords.get_cart(), spharpy_coords.cartesian.T)
+
+
 def test_coordinates_init_incomplete():
     x = [1, 2]
     y = 1
@@ -277,6 +291,24 @@ def test_sampling_sphere_init_value():
     assert isinstance(sampling, SamplingSphere)
 
 
+def test_sampling_to_pyfar_coords():
+    sampling = SamplingSphere(
+        [1], [0], [0], n_max=0, weights=np.array([4*np.pi]))
+    pyfar_coords = sampling.to_pyfar()
+    np.testing.assert_allclose(pyfar_coords.get_cart(), sampling.cartesian.T)
+    assert pyfar_coords.sh_order == sampling.n_max
+    assert pyfar_coords.weights == 1.
+
+
+def test_from_pyfar():
+    pyfar_coords = pf.Coordinates(1, 0, 0, weights=1, sh_order=0)
+    spharpy_sampling = SamplingSphere.from_pyfar(pyfar_coords)
+    np.testing.assert_allclose(
+        pyfar_coords.get_cart(), spharpy_sampling.cartesian.T)
+    assert pyfar_coords.sh_order == spharpy_sampling.n_max
+    npt.assert_almost_equal(4*np.pi, spharpy_sampling.weights)
+
+
 def sampling_cube():
     """Helper function returning a cube sampling"""
     x = [1, -1, 0, 0, 0, 0]
