@@ -1,7 +1,7 @@
 """
 Tests for modal strength function
 """
-from filehandling import read_matrix_from_mat
+from scipy.io import loadmat
 import spharpy.spherical as sh
 import numpy as np
 
@@ -10,7 +10,8 @@ def test_modal_strength_open():
     n_max = 5
     n_bins = 128
     k = np.linspace(0.5, 15, n_bins)
-    reference = read_matrix_from_mat('./tests/data/modal_strength_open.mat')
+    fname = './tests/data/modal_strength_open.mat'
+    reference = loadmat(fname)['matrix']
     bn = sh.modal_strength(n_max, k, arraytype='open')
     np.testing.assert_allclose(bn, reference)
 
@@ -20,6 +21,8 @@ def test_modal_strength_rigid():
     n_bins = 128
     k = np.linspace(0.5, 15, n_bins)
     # ref data has wrong sign (calculated as i^(n-1) instead of i^(n+1)
-    reference = -read_matrix_from_mat('./tests/data/modal_strength_rigid.mat')
+
+    fname = './tests/data/modal_strength_rigid.mat'
+    reference = -loadmat(fname)['matrix']
     bn = sh.modal_strength(n_max, k, arraytype='rigid')
     np.testing.assert_allclose(bn, reference)
